import {
  Environment,
  commonApiUrls,
  commonApiacceptableFileExtensions,
  publicApiUrls,
  externalApiUrls,
  piUrls,
  protocolUrls,
  messageApiUrls,
  promptUrls
} from './environment.type';
import { DeviceType } from '@ucap-webmessenger/core';

export const environment: Environment = {
  production: false,
  title: `[개발] DS Talk`,

  companyConfig: {
    companyGroupCode: 'LG',
    fixedCompanyCode: 'GUC100'
  },

  productConfig: {
    productId: 'PRO_000482',
    productName: 'EZMessenger',
    authentication: {
      usePrivateInformationAgree: false,
      rememberMe: {
        use: false
      },
      autoLogin: {
        use: true
      }
    },
    updateCheckConfig: {
      deviceType: DeviceType.Renderer,
      intervalHour: 1
    },
    defaultSettings: {
      general: {
        appTheme: 'theme-default',
        autoLogin: false,
        autoStart: true,
        continueRunWhenClose: true,
        locale: 'ko',
        hrInfoLocale: 'ko',
        startBackgroudMode: false,
        timezone: '+9'
      },
      notification: {
        chatMessage: true
      }
    }
  },

  customConfig: {
    pw: {
      userKey: 'DaesangSSOProject',
      isBase64: 'N'
    },
    appKey: '!@#$DAESANG%^&*',

    /** 삭제,수정 불가 그룹 Seqs:number[] */
    fixedGroupSeqs: [-5]
  },

  commonApiModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: '15.164.139.105',
      port: 8011
    },
    urls: commonApiUrls,
    acceptableFileExtensions: commonApiacceptableFileExtensions
  },

  publicApiModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: '15.164.139.105',
      port: 8011
    },
    urls: publicApiUrls
  },

  externalApiModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: '15.164.139.105',
      port: 8011
    },
    urls: externalApiUrls
  },

  messageApiModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: '15.164.139.105',
      port: 9098
    },
    urls: messageApiUrls
  },

  promptApiModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: '15.164.139.105',
      port: 9097
    },
    urls: promptUrls
  },

  piModuleConfig: {
    hostConfig: {
      protocol: 'http',
      domain: '15.164.139.105',
      port: 9097
    },
    urls: piUrls
  },

  protocolModuleConfig: {
    hostConfig: {
      protocol: 'ws',
      domain: '15.164.139.105',
      port: 8080
    },
    urls: protocolUrls,
    reconnect: {
      delay: 1000
    },
    requestId: {
      min: 1,
      max: 59999
    }
  },

  nativeModuleConfig: {}
};
